pub unsafe fn load_function_unconstrainted<F: PFN>(
interface: &(impl ResolverInterface + ?Sized),
) -> FExpand description
Loads a function using the resolver, without any constraints on the function’s type.
Safety
retrieved function must be valid function pointer of type F.