load_symbol_unconstrainted

Function load_symbol_unconstrainted 

pub unsafe fn load_symbol_unconstrainted<T: FromPtr>(
    interface: &(impl ResolverInterface + ?Sized),
    name: &CStr,
) -> T
Loads a symbol using the resolver, without any constraints on the symbol’s type.

Safety

retrieved symbol must be valid value of type T.