#[repr(C)]pub struct VkDescriptorPoolCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkDescriptorPoolCreateFlags,
pub maxSets: u32,
pub poolSizeCount: u32,
pub pPoolSizes: *const VkDescriptorPoolSize,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkDescriptorPoolCreateFlagsmaxSets: u32poolSizeCount: u32pPoolSizes: *const VkDescriptorPoolSizeTrait Implementations
Sourceimpl Clone for VkDescriptorPoolCreateInfo
impl Clone for VkDescriptorPoolCreateInfo
Sourcefn clone(&self) -> VkDescriptorPoolCreateInfo
fn clone(&self) -> VkDescriptorPoolCreateInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkDescriptorPoolCreateInfo
impl Debug for VkDescriptorPoolCreateInfo
Sourceimpl TypedVulkanStructure for VkDescriptorPoolCreateInfo
impl TypedVulkanStructure for VkDescriptorPoolCreateInfo
Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_DESCRIPTOR_POOL_CREATE_INFO
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_DESCRIPTOR_POOL_CREATE_INFO
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkDescriptorPoolCreateInfo
impl VulkanStructure for VkDescriptorPoolCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.