#[repr(C)]pub struct VkImageFormatProperties2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub imageFormatProperties: VkImageFormatProperties,
}Fields
sType: VkStructureTypepNext: *mut c_voidimageFormatProperties: VkImageFormatPropertiesTrait Implementations
Sourceimpl Clone for VkImageFormatProperties2KHR
impl Clone for VkImageFormatProperties2KHR
Sourcefn clone(&self) -> VkImageFormatProperties2KHR
fn clone(&self) -> VkImageFormatProperties2KHR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkImageFormatProperties2KHR
impl Debug for VkImageFormatProperties2KHR
Sourceimpl TypedVulkanSinkStructure for VkImageFormatProperties2KHR
Available on crate feature VK_KHR_get_physical_device_properties2 only.
impl TypedVulkanSinkStructure for VkImageFormatProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_IMAGE_FORMAT_PROPERTIES_2_KHR
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_IMAGE_FORMAT_PROPERTIES_2_KHR
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>where
Self: Sized,
fn uninit_sink() -> MaybeUninit<Self>where
Self: Sized,
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkImageFormatProperties2KHR
Available on crate feature VK_KHR_get_physical_device_properties2 only.
impl VulkanSinkStructure for VkImageFormatProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.