#[repr(C)]pub struct VkImageMemoryBarrier {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub srcAccessMask: VkAccessFlags,
pub dstAccessMask: VkAccessFlags,
pub oldLayout: VkImageLayout,
pub newLayout: VkImageLayout,
pub srcQueueFamilyIndex: u32,
pub dstQueueFamilyIndex: u32,
pub image: VkImage,
pub subresourceRange: VkImageSubresourceRange,
}Fields
sType: VkStructureTypepNext: *const c_voidsrcAccessMask: VkAccessFlagsdstAccessMask: VkAccessFlagsoldLayout: VkImageLayoutnewLayout: VkImageLayoutsrcQueueFamilyIndex: u32dstQueueFamilyIndex: u32image: VkImagesubresourceRange: VkImageSubresourceRangeTrait Implementations
Sourceimpl Clone for VkImageMemoryBarrier
impl Clone for VkImageMemoryBarrier
Sourcefn clone(&self) -> VkImageMemoryBarrier
fn clone(&self) -> VkImageMemoryBarrier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkImageMemoryBarrier
impl Debug for VkImageMemoryBarrier
Sourceimpl TypedVulkanStructure for VkImageMemoryBarrier
impl TypedVulkanStructure for VkImageMemoryBarrier
Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_IMAGE_MEMORY_BARRIER
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_IMAGE_MEMORY_BARRIER
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkImageMemoryBarrier
impl VulkanStructure for VkImageMemoryBarrier
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.