#[repr(C)]pub struct VkMemoryDedicatedAllocateInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub image: Option<VkImage>,
pub buffer: Option<VkBuffer>,
}Fields
sType: VkStructureTypepNext: *const c_voidimage: Option<VkImage>buffer: Option<VkBuffer>Trait Implementations
Sourceimpl Clone for VkMemoryDedicatedAllocateInfoKHR
impl Clone for VkMemoryDedicatedAllocateInfoKHR
Sourcefn clone(&self) -> VkMemoryDedicatedAllocateInfoKHR
fn clone(&self) -> VkMemoryDedicatedAllocateInfoKHR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Available on crate feature VK_KHR_dedicated_allocation only.
impl TypedVulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Available on crate feature
VK_KHR_dedicated_allocation only.Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_MEMORY_DEDICATED_ALLOCATE_INFO_KHR
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_MEMORY_DEDICATED_ALLOCATE_INFO_KHR
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Available on crate feature VK_KHR_dedicated_allocation only.
impl VulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Available on crate feature
VK_KHR_dedicated_allocation only.Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.