#[repr(C)]pub struct VkPhysicalDeviceImageFormatInfo2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub format: VkFormat,
pub type: VkImageType,
pub tiling: VkImageTiling,
pub usage: VkImageUsageFlags,
pub flags: VkImageCreateFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidformat: VkFormattype: VkImageTypetiling: VkImageTilingusage: VkImageUsageFlagsflags: VkImageCreateFlagsTrait Implementations
Sourceimpl Clone for VkPhysicalDeviceImageFormatInfo2KHR
impl Clone for VkPhysicalDeviceImageFormatInfo2KHR
Sourcefn clone(&self) -> VkPhysicalDeviceImageFormatInfo2KHR
fn clone(&self) -> VkPhysicalDeviceImageFormatInfo2KHR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPhysicalDeviceImageFormatInfo2KHR
Available on crate feature VK_KHR_get_physical_device_properties2 only.
impl TypedVulkanStructure for VkPhysicalDeviceImageFormatInfo2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_IMAGE_FORMAT_INFO_2_KHR
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_IMAGE_FORMAT_INFO_2_KHR
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPhysicalDeviceImageFormatInfo2KHR
Available on crate feature VK_KHR_get_physical_device_properties2 only.
impl VulkanStructure for VkPhysicalDeviceImageFormatInfo2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.