#[repr(C)]pub struct VkSemaphoreSubmitInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub semaphore: VkSemaphore,
pub value: u64,
pub stageMask: VkPipelineStageFlags2KHR,
pub deviceIndex: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidsemaphore: VkSemaphorevalue: u64stageMask: VkPipelineStageFlags2KHRdeviceIndex: u32Trait Implementations
Sourceimpl Clone for VkSemaphoreSubmitInfoKHR
impl Clone for VkSemaphoreSubmitInfoKHR
Sourcefn clone(&self) -> VkSemaphoreSubmitInfoKHR
fn clone(&self) -> VkSemaphoreSubmitInfoKHR
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSemaphoreSubmitInfoKHR
impl Debug for VkSemaphoreSubmitInfoKHR
Sourceimpl TypedVulkanStructure for VkSemaphoreSubmitInfoKHR
Available on crate feature VK_KHR_synchronization2 only.
impl TypedVulkanStructure for VkSemaphoreSubmitInfoKHR
Available on crate feature
VK_KHR_synchronization2 only.Sourceconst TYPE: VkStructureType = VK_STRUCTURE_TYPE_SEMAPHORE_SUBMIT_INFO_KHR
const TYPE: VkStructureType = VK_STRUCTURE_TYPE_SEMAPHORE_SUBMIT_INFO_KHR
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>where
Self: Sized,
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSemaphoreSubmitInfoKHR
Available on crate feature VK_KHR_synchronization2 only.
impl VulkanStructure for VkSemaphoreSubmitInfoKHR
Available on crate feature
VK_KHR_synchronization2 only.Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.