VulkanSinkStructure

Trait VulkanSinkStructure 

pub unsafe trait VulkanSinkStructure {
    // Required methods
    fn as_generic(&self) -> &GenericVulkanSinkStructure;
    fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure;
}
Trait for Vulkan structures that can be cast to GenericVulkanSinkStructure safely.

Safety

self must be a valid Vulkan structure type.

Required Methods

fn as_generic(&self) -> &GenericVulkanSinkStructure

Cast this structure ref to generic one. This is same as transmute but must be safe.

fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure

Cast this structure mutable ref to generic one. This is same as transmute but must be safe.

Implementations on Foreign Types

Source

impl<T> VulkanSinkStructure for &mut T

Source

impl<T> VulkanSinkStructure for Box<T>

Implementors

Source

impl VulkanSinkStructure for VkFormatProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkImageFormatProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkMemoryDedicatedRequirementsKHR

Available on crate feature VK_KHR_dedicated_allocation only.
Source

impl VulkanSinkStructure for VkMemoryRequirements2KHR

Available on crate feature VK_KHR_get_memory_requirements2 only.
Source

impl VulkanSinkStructure for VkPhysicalDeviceFeatures2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkPhysicalDeviceMemoryProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkPhysicalDeviceProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR

Available on crate feature VK_KHR_synchronization2 only.
Source

impl VulkanSinkStructure for VkQueueFamilyProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkSparseImageFormatProperties2KHR

Available on crate feature VK_KHR_get_physical_device_properties2 only.
Source

impl VulkanSinkStructure for VkSparseImageMemoryRequirements2KHR

Available on crate feature VK_KHR_get_memory_requirements2 only.