pub trait ResolverInterface {
// Required methods
unsafe fn load_symbol_unconstrainted(&self, name: &CStr) -> NonNull<c_void>;
unsafe fn load_function_unconstrainted(
&self,
name: &CStr,
) -> PFN_vkVoidFunction;
}Required Methods
Sourceunsafe fn load_symbol_unconstrainted(&self, name: &CStr) -> NonNull<c_void>
unsafe fn load_symbol_unconstrainted(&self, name: &CStr) -> NonNull<c_void>
Loads a symbol using the resolver, without any constraints on the symbol’s type.
Safety
retrieved symbol must be valid value of type T.
Sourceunsafe fn load_function_unconstrainted(&self, name: &CStr) -> PFN_vkVoidFunction
unsafe fn load_function_unconstrainted(&self, name: &CStr) -> PFN_vkVoidFunction
Loads a function using the resolver, without any constraints on the function’s type.
Safety
retrieved function must be valid function pointer of type F.