pub unsafe trait VulkanSinkStructure {
// Required methods
fn as_generic(&self) -> &GenericVulkanSinkStructure;
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure;
}Expand description
Trait for Vulkan structures that can be cast to GenericVulkanSinkStructure safely.
Safety
self must be a valid Vulkan structure type.
Required Methods
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.
Implementations on Foreign Types
Sourceimpl<T> VulkanSinkStructure for &mut Twhere
T: VulkanSinkStructure,
impl<T> VulkanSinkStructure for &mut Twhere
T: VulkanSinkStructure,
fn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Sourceimpl<T> VulkanSinkStructure for Box<T>where
T: VulkanSinkStructure + ?Sized,
impl<T> VulkanSinkStructure for Box<T>where
T: VulkanSinkStructure + ?Sized,
fn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Implementors
impl VulkanSinkStructure for VkFormatProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkImageFormatProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkMemoryDedicatedRequirementsKHR
Available on crate feature
VK_KHR_dedicated_allocation only.impl VulkanSinkStructure for VkMemoryRequirements2KHR
Available on crate feature
VK_KHR_get_memory_requirements2 only.impl VulkanSinkStructure for VkPhysicalDeviceFeatures2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkPhysicalDeviceMemoryProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkPhysicalDeviceProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
Available on crate feature
VK_KHR_synchronization2 only.impl VulkanSinkStructure for VkQueueFamilyProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkSparseImageFormatProperties2KHR
Available on crate feature
VK_KHR_get_physical_device_properties2 only.impl VulkanSinkStructure for VkSparseImageMemoryRequirements2KHR
Available on crate feature
VK_KHR_get_memory_requirements2 only.